<?php

namespace MDT\CHP;

/**
 * Add some filters/actions to display legal notices
 *
 * Class Notices
 *
 * @package MDT
 */
class Notices {

	/**
	 * Notices constructor
	 */
	function __construct() {
		add_filter( 'wp_prepare_attachment_for_js', [ __CLASS__, 'append_chp_notices_class' ], 10, 2 );
		add_action( 'admin_enqueue_scripts', [ __CLASS__, 'enqueue_scripts' ] );
		add_action( 'enqueue_block_editor_assets', [ __CLASS__, 'enqueue_gutenberg_scripts' ] );
		add_filter( 'rest_prepare_attachment', [ __CLASS__, 'add_additional_meta_chp_legal_notice' ], 10, 2 );
	}

	/**
	 * Append the chp-notice class under certain conditions
	 *
	 * @param array $response
	 * @param object $attachment
	 *
	 * @return array
	 */
	public static function append_chp_notices_class( array $response, object $attachment ): array {

		if ( self::has_legal_notice( $attachment->ID ) ) {
			$response['chpNoticeClass'] = "chp-notice";
		}

		return $response;
	}

	/**
	 * Whether or not the image has a legal notice
	 *
	 * @param int $attachment_id
	 *
	 * @return bool
	 */
	public static function has_legal_notice( int $attachment_id ): bool {

		$has_legal_notice = false;

		$chp_notices = get_post_meta( $attachment_id, Settings::CHP_NOTICES_META_KEY, true );

		if ( empty( $chp_notices ) ) {
			return $has_legal_notice;
		}

		$data = json_decode( $chp_notices, true );

		if ( is_array( $data ) && isset( $data['Notices'] ) ) {
			// Check if there is a notice with Type "Legal"
			$has_legal_notice = isset( $data['Notices']['Notice'] ) && ! empty( array_filter( $data['Notices']['Notice'], function ( $notice ) {
					return $notice['Type'] === 'Legal';
				} ) );
		}

		return $has_legal_notice;
	}

	/**
	 * Enqueue JavaScript and CSS files for the wp-admin
	 *
	 * @return void
	 */
	public static function enqueue_scripts(): void {

		$currentScreen = get_current_screen();

		if ( in_array ( $currentScreen->base, array( 'post', 'upload' ), true ) ) {

			wp_enqueue_style(
				'append-chp-notices-class-css',
				plugins_url( 'chp-usage/src/index.css' ), [], Utils::get_plugin_version()
			);

			wp_enqueue_script( 'append-chp-notices-class-js', plugins_url( 'chp-usage/src/js/chp-notices.js' ), [], Utils::get_plugin_version() );

		}

		// Check if we are on the media edit page
		if ( get_post_type() === 'attachment' ) {
			wp_localize_script( 'append-chp-notices-class-js', 'metaData', array(
				'hasLegalNotice' => self::has_legal_notice( get_the_ID() )
			) );
		}
	}

	/**
	 * Enqueue JavaScript files for the gutenberg editor
	 *
	 * @return void
	 */
	public static function enqueue_gutenberg_scripts(): void {
		wp_enqueue_script(
			'append-chp-notices-gutenberg-js',
			plugins_url( 'chp-usage/build/index.js' ),
			array( 'wp-blocks', 'wp-hooks', 'wp-element', 'wp-editor' ),
			Utils::get_plugin_version(),
			true
		);
	}

	/**
	 * Modify the data and return the chp_legal_notice info as boolean
	 *
	 * @param WP_REST_Response $response
	 * @param WP_Post $post
	 *
	 * @return object
	 */
	public static function add_additional_meta_chp_legal_notice( object $response, object $post ): object {
		if ( ! is_array( $response->data ) ) {
			return $response;
		}

		$additional_meta = array(
			'chp_legal_notice' => self::has_legal_notice( $post->ID )
		);

		$response->data['meta'] = array_merge( $response->data['meta'] ?? array(), $additional_meta );

		return $response;
	}
}

new Notices();
